@@ -1,10 +1,10 @@
 """
-ksubscribe
+Ksubscribe
 
 An event-based programming methodology for Python coders!
 """
 
-__version__ = "1.0.5"
+__version__ = "1.0.7"
 __author__ = 'Osman Onur KUZUCU'
 __credits__ = 'KZC Software Inc.'
 
@@ -36,23 +36,34 @@ class Ksubscribe(metaclass=KsubscribeSingletonMeta):
     def __init__(self):
         self.__eventList={}  
 
+    
     def _subscribeForAnEvent(self,subscriber,eventName:str):
         try:
             if(self.__eventList.get(eventName) != None):
                 self.__eventList[eventName].append(subscriber)
             else:
-                print("EventBasedFramework : Cannot subscribe an event. Because the event is not exist in event collections")
+                self._createAnEvent(eventName)
+                self._subscribeForAnEvent(subscriber,eventName)
+                print("Ksubsribe : There is not an event. Because the event is not exist in event collections. KSubscribe has created an event to subscribe.")
+            return True
+
         except Exception as e:
-            print("EventBasedFramework :",e)
+            print("Ksubsribe : ",e)
+            return False
 
     def _createAnEvent(self, eventName:str):
         try:
             if(self.__eventList.get(eventName) == None):
                 self.__eventList[eventName] = []
+                return True
+
             else:
-                print("EventBasedFramework : Cannot create an event. Because the event is exist in event collections")
+                print("Ksubsribe : Cannot create an event. Because the event is exist in event list")
+                return False
+
         except Exception as e:
-            print("EventBasedFramework :",e)
+            print("Ksubsribe : ",e)
+            return False
 
 
 
@@ -62,25 +73,51 @@ class Ksubscribe(metaclass=KsubscribeSingletonMeta):
                 for x in self.__eventList[eventName]:
                     x.inform(eventName,parameters)
             else:
-                print("EventBasedFramework : Cannot subscribe an event. Because the event is not exist in event collections")
+                print("Ksubsribe : Cannot publish an event. Because the event is not exist in event list")
         except Exception as e:
-            print("EventBasedFramework :",e)
+            print("Ksubsribe : ",e)
 
     def _removeAnEvent(self,eventName:str):
         try:
             if(self.__eventList.get(eventName) != None):
                 self.__eventList.pop(eventName)
+                return True
+
             else:
-                print("EventBasedFramework : Cannot subscribe an event. Because the event is not exist in event collections")
+                print("Ksubsribe : Cannot remove an event. Because the event is not exist in event list")
+                return False
+
         except Exception as e:
-            print("EventBasedFramework :",e)
+            print("Ksubsribe : ",e)
+            return False
 
     def _removeAllEvents(self):
         try:
             if(len(self.__eventList)>0):
                 self.__eventList.clear()
+                return True
             else:
-                print("EventBasedFramework : Cannot subscribe an event. Because the event is not exist in event collections")
+                print("Ksubsribe : Cannot remove all events. Because there is not events in event list")
+                return False
+
         except Exception as e:
-            print("EventBasedFramework :",e)
+            print("Ksubsribe : ",e)
+            return False
+
+    def _removeSubscriberFromEvent(self,subscriber, eventName:str):
+        try:
+            if(self.__eventList.get(eventName) != None):
+                if(subscriber in self.__eventList.get(eventName)):
+                    self.__eventList.get(eventName).remove(subscriber)
+                    return True
+                else:
+                    print("Ksubsribe : The subscriber does not in event subscriber list")
+                    return False
+            else:
+                print("Ksubsribe : Cannot remove subscriber. Because the event is not exist in event collections")
+                return False
+
+        except Exception as e:
+            print("Ksubsribe : ",e)
+            return False
     
